@@ -1,7 +1,6 @@
 package Scrappy::Action;
-
 BEGIN {
-    $Scrappy::Action::VERSION = '0.9111180';
+  $Scrappy::Action::VERSION = '0.9111190';
 }
 
 use Moose;
@@ -31,17 +30,19 @@ has registry => (
 );
 
 sub actions {
-    my @actions = ();
+    my  @actions = ();
 
-    my @files =
-      File::Find::Rule->file()->name('*.pm')
-      ->in(map {"$_/Scrappy/Action"} @INC);
+    my  @files =
+        File::Find::Rule->file()->name('*.pm')
+        ->in(map {"$_/Scrappy/Action"} @INC);
 
-    my %actions = map { $_ => 1 } @files;    #uniquenes
+    my  %actions =
+        map { $_ => 1 }
+            map { s/.*(Scrappy[\\\/]Action[\\\/].*\.pm)/$1/; $_ } @files; #uniquenes
 
     for my $action (keys %actions) {
 
-        my ($plug) = $action =~ /(Scrappy\/Action\/.*)\.pm/;
+        my ($plug) = $action =~ /(Scrappy[\\\/]Action[\\\/].*)\.pm/;
 
         if ($plug) {
             $plug =~ s/\//::/g;
@@ -54,8 +55,8 @@ sub actions {
 }
 
 sub load_action {
-    my $self   = shift;
-    my $action = shift;
+    my $self    = shift;
+    my $action  = shift;
 
     unless ($action =~ /^Scrappy::Action::/) {
 
@@ -79,60 +80,54 @@ sub load_action {
     elsif ($self->registry->{lc($action)}) {
         return $self->registry->{lc($action)};
     }
-
+    
     return 0;
 }
 
 # execute an action from the cli
 sub execute {
     my ($class, $action_class, $action, @options) = @_;
-    my $self = ref $class ? $class : $class->new;
-
-    # show help on syntax error
-    if (!$action_class || $action_class eq 'help') {
-
-        with 'Scrappy::Action::Help';
-        print $self->menu;
-        exit;
-
-    }
-    else {
-        if ($action) {
-            if (   $action eq 'meta'
-                || $action eq 'registry'
-                || $action eq 'actions'
-                || $action eq 'load_action'
-                || $action eq 'execute')
-            {
-
-                with 'Scrappy::Action::Help';
-                print $self->menu;
-                exit;
+    my  $self = ref $class ? $class : $class->new;
+    
+        # show help on syntax error
+        if (!$action_class || $action_class eq 'help') {
+            
+            with 'Scrappy::Action::Help';
+            print $self->menu;
+            exit;
+            
+        }
+        else {
+            if ($action) {
+                if ($action eq 'meta' || $action eq 'registry' ||
+                    $action eq 'actions' || $action eq 'load_action' ||
+                    $action eq 'execute') {
+                    
+                    with 'Scrappy::Action::Help';
+                    print $self->menu;
+                    exit;
+                }
             }
         }
-    }
-
+    
     # locate the action if installed
-    my $requested_action = $self->load_action($action_class);
-
+    my  $requested_action = $self->load_action($action_class);
+    
     if ($requested_action) {
-
         # load the desired action class
         with $requested_action;
-
+        
         # is actoin available
         unless ($action) {
             print $self->help($requested_action);
             exit;
         }
-
+        
         # run the requested action
-        print $self->meta->has_method($action)
-          ? $self->$action(@options)
-          : $self->help($requested_action);
+        print $self->meta->has_method($action) ?
+            $self->$action(@options) : $self->help($requested_action);
     }
     else {
-
         # ... or display the help menu
         with 'Scrappy::Action::Help';
         print $self->menu;
