@@ -1,7 +1,6 @@
 package Scrappy::Plugin;
-
 BEGIN {
-    $Scrappy::Plugin::VERSION = '0.9111180';
+  $Scrappy::Plugin::VERSION = '0.9111190';
 }
 
 # load OO System
@@ -39,7 +38,9 @@ has plugins => (
           File::Find::Rule->file()->name('*.pm')
           ->in(map {"$_/Scrappy/Plugin"} @INC);
 
-        my %plugins = map { $_ => 1 } @files;    #uniquenes
+        my %plugins =
+            map { $_ => 1 }
+                map { s/.*(Scrappy[\\\/]Plugin[\\\/].*\.pm)/$1/; $_ } @files; #uniquenes
 
         for my $plugin (keys %plugins) {
 
