@@ -1,7 +1,6 @@
 package Scrappy::Session;
-
 BEGIN {
-    $Scrappy::Session::VERSION = '0.9111180';
+  $Scrappy::Session::VERSION = '0.9111190';
 }
 
 # load OO System
@@ -20,10 +19,11 @@ sub load {
 
         $self->{file} = $file;
 
+        croak("Session file $file does not exist or is not read/writable")
+            unless -f $file;
+
         # load session file
-        $self->{stash} = LoadFile($file)
-          or
-          croak("Session file $file does not exist or is not read/writable");
+        $self->{stash} = LoadFile($file);
     }
 
     return $self->{stash};
@@ -65,9 +65,10 @@ sub write {
     if ($file) {
 
         # write session file
-        DumpFile($file, $self->{stash})
-          or
-          croak("Session file $file does not exist or is not read/writable");
+        croak("Session file $file does not exist or is not read/writable")
+            unless -f $file;
+
+        DumpFile($file, $self->{stash});
     }
 
     return $self->{stash};
